import React from 'react'
import { translate } from 'cozy-ui/react/I18n'

import { Konnector } from 'doctypes'
import OAuthForm from 'components/ContentComponents/OAuth/OAuthForm'
import StyledButton from 'components/CommonKit/Button/StyledButton'

interface KonnectorOAuthFormProps {
  konnector: Konnector
  siteLink: string
  onSuccess: Function
  loading: boolean
  t: Function
}

const KonnectorOAuthForm: React.FC<KonnectorOAuthFormProps> = ({
  konnector,
  siteLink,
  onSuccess,
  loading,
  t,
}: KonnectorOAuthFormProps) => {
  return (
    <div className="koauthform">
      <div className="koauthform-text text-16-normal">
        {t('oauth.connect.' + konnector.slug + '.info')}
      </div>
      <div className="koauthform-button">
        <OAuthForm konnector={konnector} onSuccess={onSuccess} />
      </div>
      <div className="koauthform-text text-16-bold">
        <div className="text-16-bold">
          {t('oauth.no_account.' + konnector.slug + '.title')}
        </div>
        <div className="text-16-normal">
          {t('oauth.no_account.' + konnector.slug + '.text')}
        </div>
      </div>
      <div className="koauthform-button">
        <StyledButton
          type="button"
          color="secondary"
          disabled={loading}
          onClick={() => window.open(siteLink, '_blank')}
        >
          {t('oauth.create_account.' + konnector.slug)}
        </StyledButton>
      </div>
    </div>
  )
}

export default translate()(KonnectorOAuthForm)
